pygeodesy.triaxials.bases.LLK

Package pygeodesy :: Package triaxials :: Module bases :: Class LLK |
[frames] | no frames]

# Class LLK

    object --+
             |
            LLK

Enum-like `Lat-/Longitude Kinds (LLK)`, see coord.

Instance Methods
__getitem__(self, name) |
get(self, name, dflt=None) Get an `LLK` by `name`. |
items(self) Yield all `LLK (name, value)` pairs. |
keys(self) Yield all `LLK` names. |
values(self) Yield all `LLK` values. |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables
| CONFORMAL = `'CONFORMAL'`
| ELLIPSOIDAL = `'ELLIPSOIDAL'`
| GEOCENTRIC = `'GEOCENTRIC'`
| GEOCENTRIC_X = `'GEOCENTRIC_X'`
| GEODETIC = `'GEODETIC'`
| GEODETIC_LON0 = `'GEODETIC_LON0'`
| GEODETIC_X = `'GEODETIC_X'`
| GEOGRAPHIC = `'GEODETIC'`
| PARAMETRIC = `'PARAMETRIC'`
| PARAMETRIC_X = `'PARAMETRIC_X'`
| PLANETOCENTRIC = `'GEOCENTRIC'`
| PLANETODETIC = `'GEODETIC'`

Properties
Inherited from `object`: `__class__`